_`umbra.preferences`
====================

.. automodule:: umbra.preferences

Module Attributes
-----------------

.. attribute:: umbra.preferences.LOGGER

Classes
-------

.. autoclass:: Preferences
	:show-inheritance:
	:members:

